package org.kaveh.commons.farsi.expression;

import org.kaveh.commons.farsi.access.FarsiString;
import org.kaveh.commons.farsi.constatns.ArabicLetterConstants;
import org.kaveh.commons.farsi.constatns.FarsiLetterConstants;
import org.kaveh.commons.farsi.constatns.LatinLetterConstants;
import org.kaveh.commons.farsi.letter.LatinLetter;
import org.kaveh.commons.farsi.punctuation.FarsiPunctuation;
import org.kaveh.commons.farsi.utils.ConstantReflectionUtilies;
import org.kaveh.commons.farsi.word.FarsiWord;

public class FarsiStringImpl implements FarsiString {

	String farsiString;

	public FarsiStringImpl(String farsiString) {
		this.farsiString = farsiString;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.kaveh.commons.farsi.access.FarsiString#farsIze()
	 */
	public String farsIze() {
		return farsIze(farsiString);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.kaveh.commons.farsi.access.FarsiString#farsIze()
	 */
	public static String farsIze(String inputExpression) {
		String result = inputExpression;
		result = FarsiWord.replaceArabicDigit(result);
		result = FarsiWord.replaceLatinDigit(result);
		result = FarsiWord.replaceArabicLetters(result);
		return result;
	}

	public static String normalizeString(String input) {
		input = ConstantReflectionUtilies.getFixedString(input, LatinLetterConstants.Digits.class, FarsiLetterConstants.Digits.class);
		input = ConstantReflectionUtilies.getFixedString(input, ArabicLetterConstants.Digits.class, FarsiLetterConstants.Digits.class);
		input = ConstantReflectionUtilies.getFixedString(input, ArabicLetterConstants.Consonants.class, FarsiLetterConstants.Consonants.class);
		input = FarsiPunctuation.fixPunctuation(input);
		return input;
	}

	public static boolean isAllLatinLetters(String inputString) {
		for (int i = 0; i < inputString.length(); i++) {
			if (!LatinLetter.isLatinLetter(inputString.charAt(i))) {
				return false;
			}
		}

		return true;
	}

	@Override
	public String toString() {
		return normalizeString(farsiString);
	}

}
